Package: OnassisJavaLibs
Type: Package
Title: OnassisJavaLibs, java libraries to run conceptmapper and
        semantic similarity
Version: 1.32.0
Author: Eugenia Galeota
Authors@R: person("Eugenia", "Galeota",
        email="eugenia.galeota@gmail.com", role=c("aut", "cre"))
Maintainer: Eugenia Galeota <eugenia.galeota@gmail.com>
Description: A package that contains java libraries to call
        conceptmapper and compute semnatic similarity from R
License: GPL-2
Depends: R (>= 3.4)
Imports: rJava
Suggests: BiocStyle, rmarkdown, knitr
VignetteBuilder: rmarkdown, knitr
SystemRequirements: Java (>= 1.8)
Encoding: UTF-8
biocViews: ExperimentData
NeedsCompilation: no
RoxygenNote: 6.0.1
git_url: https://git.bioconductor.org/packages/OnassisJavaLibs
git_branch: RELEASE_3_22
git_last_commit: 28145a9
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-04
Packaged: 2025-11-04 16:35:15 UTC; biocbuild
