Sglib - Semantic Graph Library
========================

Sglib is a JAVA library dedicated to in memory semantic graph processing.
The graph model considered is based on:
- vertices as URI
- edges as triplet <s,p,o> of URIs



        